@@ -12,16 +12,15 @@
  * for more details.
  */
 
-#ifndef SOCKETAPI_H
-#define SOCKETAPI_H
+#pragma once
+
+#include "gui/owncloudguilib.h"
 
 #include "syncfileitem.h"
 #include "common/syncfilestatus.h"
 #include "sharedialog.h" // for the ShareDialogStartPage
 #include "common/syncjournalfilerecord.h"
 
-#include "config.h"
-
 #if defined(Q_OS_MAC)
 #include "socketapisocket_mac.h"
 #else
@@ -32,7 +31,6 @@ using SocketApiSocket = QLocalSocket;
 
 class QUrl;
 class QLocalSocket;
-class QStringList;
 
 namespace OCC {
 
@@ -48,7 +46,7 @@ Q_DECLARE_LOGGING_CATEGORY(lcSocketApi)
  * @brief The SocketApi class
  * @ingroup gui
  */
-class SocketApi : public QObject
+class OWNCLOUDGUI_EXPORT SocketApi : public QObject
 {
     Q_OBJECT
 
@@ -56,7 +54,9 @@ public:
     explicit SocketApi(QObject *parent = nullptr);
     ~SocketApi() override;
 
-public slots:
+    void startShellIntegration();
+
+public Q_SLOTS:
     void registerAccount(const AccountPtr &a);
     void unregisterAccount(const AccountPtr &a);
     void slotUpdateFolderView(Folder *f);
@@ -64,10 +64,10 @@ public slots:
     void slotRegisterPath(Folder *f);
     void broadcastStatusPushMessage(const QString &systemPath, SyncFileStatus fileStatus);
 
-signals:
+Q_SIGNALS:
     void shareCommandReceived(const QString &sharePath, const QString &localPath, ShareDialogStartPage startPage);
 
-private slots:
+private Q_SLOTS:
     void slotNewConnection();
     void slotReadSocket();
 
@@ -158,11 +158,10 @@ private:
 
     QString buildRegisterPathMessage(const QString &path);
 
+    QString _socketPath;
     QSet<Folder *> _registeredFolders;
     QSet<AccountPtr> _registeredAccounts;
     QMap<SocketApiSocket *, QSharedPointer<SocketListener>> _listeners;
     SocketApiServer _localServer;
 };
 }
-
-#endif // SOCKETAPI_H
