@@ -15,6 +15,8 @@
 #ifndef UPDATER_H
 #define UPDATER_H
 
+#include "gui/owncloudguilib.h"
+
 #include <QLoggingCategory>
 #include <QObject>
 
@@ -25,7 +27,7 @@ namespace OCC {
 
 Q_DECLARE_LOGGING_CATEGORY(lcUpdater)
 
-class Updater : public QObject
+class OWNCLOUDGUI_EXPORT Updater : public QObject
 {
     Q_OBJECT
 public:
@@ -34,7 +36,12 @@ public:
 
     virtual void checkForUpdate() = 0;
     virtual void backgroundCheckForUpdate() = 0;
-    virtual bool handleStartup() = 0;
+    virtual void validateUpdate();
+
+    /***
+     * This function will just restart on most platforms
+    */
+    virtual void applyUpdateAndRestart();
 
 protected:
     Updater()
@@ -43,7 +50,6 @@ protected:
     }
 
 private:
-    static QString getSystemInfo();
     static QUrlQuery getQueryParams();
     static Updater *create();
     static Updater *_instance;
