@@ -28,7 +28,7 @@
 #include "syncoptions.h"
 #include "syncfileitem.h"
 
-#include "csync/csync_exclude.h"
+class ExcludedFiles;
 
 namespace OCC {
 
@@ -89,14 +89,14 @@ public:
     explicit DiscoverySingleLocalDirectoryJob(const AccountPtr &account, const QString &localPath, OCC::Vfs *vfs, QObject *parent = nullptr);
 
     void run() override;
-signals:
+Q_SIGNALS:
     void finished(QVector<LocalInfo> result);
     void finishedFatalError(QString errorString);
     void finishedNonFatalError(QString errorString);
 
     void itemDiscovered(SyncFileItemPtr item);
     void childIgnored(bool b);
-private slots:
+private Q_SLOTS:
 private:
     QString _localPath;
     AccountPtr _account;
@@ -122,15 +122,14 @@ public:
     void abort();
 
     // This is not actually a network job, it is just a job
-signals:
+Q_SIGNALS:
     void firstDirectoryPermissions(RemotePermissions);
     void etag(const QString &, const QDateTime &time);
     void finished(const HttpResult<QVector<RemoteInfo>> &result);
 
-private slots:
+private Q_SLOTS:
     void directoryListingIteratedSlot(const QString &, const QMap<QString, QString> &);
     void lsJobFinishedWithoutErrorSlot();
-    void lsJobFinishedWithErrorSlot(QNetworkReply *);
 
 private:
     QVector<RemoteInfo> _results;
@@ -206,18 +205,13 @@ class DiscoveryPhase : public QObject
     int _currentlyActiveJobs = 0;
 
     // both must contain a sorted list
-    QStringList _selectiveSyncBlackList;
-    QStringList _selectiveSyncWhiteList;
+    std::set<QString> _selectiveSyncBlackList;
+    std::set<QString> _selectiveSyncWhiteList;
 
     void scheduleMoreJobs();
 
     bool isInSelectiveSyncBlackList(const QString &path) const;
 
-    // Check if the new folder should be deselected or not.
-    // May be async. "Return" via the callback, true if the item is blacklisted
-    void checkSelectiveSyncNewFolder(const QString &path, RemotePermissions rp,
-        const std::function<void(bool)> &callback);
-
     /** Given an original path, return the target path obtained when renaming is done.
      *
      * Note that it only considers parent directory renames. So if A/B got renamed to C/D,
@@ -254,15 +248,15 @@ public:
     QString _remoteFolder; // remote folder, ends with '/'
     SyncJournalDb *_statedb;
     ExcludedFiles *_excludes;
-    QRegExp _invalidFilenameRx; // FIXME: maybe move in ExcludedFiles
+    QRegularExpression _invalidFilenameRx; // FIXME: maybe move in ExcludedFiles
     QStringList _serverBlacklistedFiles; // The blacklist from the capabilities
     bool _ignoreHiddenFiles = false;
     std::function<bool(const QString &)> _shouldDiscoverLocaly;
 
     void startJob(ProcessDirectoryJob *);
 
-    void setSelectiveSyncBlackList(const QStringList &list);
-    void setSelectiveSyncWhiteList(const QStringList &list);
+    void setSelectiveSyncBlackList(const QSet<QString> &list);
+    void setSelectiveSyncWhiteList(const QSet<QString> &list);
 
     // output
     QByteArray _dataFingerprint;
@@ -273,20 +267,17 @@ public:
      */
     bool isSpace() const;
 
-signals:
+Q_SIGNALS:
     void fatalError(const QString &errorString);
     void itemDiscovered(const SyncFileItemPtr &item);
     void finished();
 
-    // A new folder was discovered and was not synced because of the confirmation feature
-    void newBigFolder(const QString &folder, bool isExternal);
-
     /** For excluded items that don't show up in itemDiscovered()
       *
       * The path is relative to the sync folder, similar to item->_file
       */
     void silentlyExcluded(const QString &folderPath);
-    void excluded(const QString &folderPath, CSYNC_EXCLUDE_TYPE reason);
+    void excluded(const QString &folderPath);
 };
 
 /// Implementation of DiscoveryPhase::adjustRenamedPath
