@@ -17,8 +17,6 @@
 #include "theme.h"
 
 #include <QCoreApplication>
-#include <QDir>
-#include <QStringList>
 #include <QtConcurrent>
 #include <QtGlobal>
 
@@ -54,12 +52,12 @@ namespace OCC {
 Logger *Logger::instance()
 {
     static auto *log = [] {
-        auto log = new Logger;
+        auto _log = new Logger;
         qAddPostRoutine([] {
             Logger::instance()->close();
             delete Logger::instance();
         });
-        return log;
+        return _log;
     }();
     return log;
 }
@@ -80,7 +78,7 @@ Logger::Logger(QObject *parent)
 Logger::~Logger()
 {
 #ifndef NO_MSG_HANDLER
-    qInstallMessageHandler(0);
+    qInstallMessageHandler(nullptr);
 #endif
 }
 
@@ -92,7 +90,7 @@ QString Logger::loggerPattern()
 bool Logger::isLoggingToFile() const
 {
     QMutexLocker lock(&_mutex);
-    return _logstream;
+    return !_logstream.isNull();
 }
 
 void Logger::doLog(QtMsgType type, const QMessageLogContext &ctx, const QString &message)
@@ -145,7 +143,7 @@ void Logger::open(const QString &name)
         return;
     }
     _logstream.reset(new QTextStream(&_logFile));
-    _logstream->setCodec("UTF-8");
+    _logstream->setEncoding(QStringConverter::Utf8);
     (*_logstream) << Theme::instance()->aboutVersions(Theme::VersionFormat::OneLiner) << " " << qApp->applicationName() << Qt::endl;
 }
 
@@ -245,7 +243,7 @@ void Logger::dumpCrashLog()
     QFile logFile(QStringLiteral("%1/%2-crash.log").arg(QDir::tempPath(), qApp->applicationName()));
     if (logFile.open(QFile::WriteOnly)) {
         QTextStream out(&logFile);
-        out.setCodec("UTF-8");
+        out.setEncoding(QStringConverter::Utf8);
         for (int i = 1; i <= crashLogSizeC; ++i) {
             out << _crashLog[(_crashLogIndex + i) % crashLogSizeC];
         }
@@ -293,7 +291,8 @@ void Logger::rotateLog()
         // rename previous log file if size != 0
         const auto info = QFileInfo(logName);
         if (info.exists(logName) && info.size() != 0) {
-            previousLog = dir.filePath(QStringLiteral("%1-%2.log").arg(qApp->applicationName(), info.created().toString(QStringLiteral("MMdd_hh.mm.ss.zzz"))));
+            previousLog =
+                dir.filePath(QStringLiteral("%1-%2.log").arg(qApp->applicationName(), info.birthTime().toString(QStringLiteral("MMdd_hh.mm.ss.zzz"))));
             if (!QFile(logName).rename(previousLog)) {
                 std::cerr << "Failed to rename: " << qPrintable(logName) << " to " << qPrintable(previousLog) << std::endl;
             }
@@ -304,7 +303,7 @@ void Logger::rotateLog()
         // set the creation time to now
         _logFile.setFileTime(now, QFileDevice::FileTime::FileBirthTime);
 
-        QtConcurrent::run([now, previousLog, dir, maxLogFiles = _maxLogFiles] {
+        std::ignore = QtConcurrent::run([now, previousLog, dir, maxLogFiles = _maxLogFiles] {
             // Compress the previous log file.
             if (!previousLog.isEmpty() && QFileInfo::exists(previousLog)) {
                 QString compressedName = QStringLiteral("%1.gz").arg(previousLog);
@@ -321,7 +320,7 @@ void Logger::rotateLog()
 
                 // keeping the last maxLogFiles files in total (need to subtract one from maxLogFiles to ensure the limit)
                 std::sort(oldLogFiles.begin(), oldLogFiles.end(), std::greater<QString>());
-                oldLogFiles.erase(oldLogFiles.begin(), oldLogFiles.begin() + std::min(maxLogFiles - 1, oldLogFiles.size()));
+                oldLogFiles.erase(oldLogFiles.begin(), oldLogFiles.begin() + std::min<qsizetype>(maxLogFiles - 1, oldLogFiles.size()));
 
                 for (const auto &s : oldLogFiles) {
                     if (!QFile::remove(dir.absoluteFilePath(s))) {
