@@ -31,8 +31,10 @@ public:
 
     void migrate() override;
 
+    void startServices() override;
+
 private:
-    Q_DECLARE_PRIVATE(MacPlatform);
+    Q_DECLARE_PRIVATE(MacPlatform)
     QScopedPointer<MacPlatformPrivate> d_ptr;
 };
 
