@@ -7,10 +7,23 @@
 
 #include <QtTest>
 
+#include "common/chronoelapsedtimer.h"
 #include "common/utility.h"
 #include "folderwatcher.h"
 #include "testutils/testutils.h"
 
+using namespace std::chrono_literals;
+
+namespace {
+class FolderWatcherForTests : public OCC::FolderWatcher
+{
+    Q_OBJECT
+public:
+    using OCC::FolderWatcher::FolderWatcher;
+
+    bool pathIsIgnored(const QString &) const override { return false; }
+};
+
 void touch(const QString &file)
 {
 #ifdef Q_OS_WIN
@@ -19,7 +32,7 @@ void touch(const QString &file)
     QString cmd;
     cmd = QStringLiteral("touch %1").arg(file);
     qDebug() << "Command: " << cmd;
-    system(cmd.toLocal8Bit());
+    system(cmd.toLocal8Bit().constData());
 #endif
 }
 
@@ -31,7 +44,7 @@ void mkdir(const QString &file)
 #else
     QString cmd = QStringLiteral("mkdir %1").arg(file);
     qDebug() << "Command: " << cmd;
-    system(cmd.toLocal8Bit());
+    system(cmd.toLocal8Bit().constData());
 #endif
 }
 
@@ -43,7 +56,7 @@ void rmdir(const QString &file)
 #else
     QString cmd = QStringLiteral("rmdir %1").arg(file);
     qDebug() << "Command: " << cmd;
-    system(cmd.toLocal8Bit());
+    system(cmd.toLocal8Bit().constData());
 #endif
 }
 
@@ -54,7 +67,7 @@ void rm(const QString &file)
 #else
     QString cmd = QStringLiteral("rm %1").arg(file);
     qDebug() << "Command: " << cmd;
-    system(cmd.toLocal8Bit());
+    system(cmd.toLocal8Bit().constData());
 #endif
 }
 
@@ -65,9 +78,10 @@ void mv(const QString &file1, const QString &file2)
 #else
     QString cmd = QStringLiteral("mv %1 %2").arg(file1, file2);
     qDebug() << "Command: " << cmd;
-    system(cmd.toLocal8Bit());
+    system(cmd.toLocal8Bit().constData());
 #endif
 }
+}
 
 using namespace OCC;
 
@@ -77,14 +91,15 @@ class TestFolderWatcher : public QObject
 
     const QTemporaryDir _root = TestUtils::createTempDir();
     QString _rootPath;
-    QScopedPointer<FolderWatcher> _watcher;
+    QScopedPointer<FolderWatcherForTests> _watcher;
     QScopedPointer<QSignalSpy> _pathChangedSpy;
 
     bool waitForPathChanged(const QString &path)
     {
-        QElapsedTimer t;
-        t.start();
-        while (t.elapsed() < 5000) {
+        Utility::ChronoElapsedTimer t;
+        // Current interval is 10s, if we didn't get a change in 15s something did not work
+        // https://github.com/owncloud/client/blob/82b5a1e1bb2b05503e0774d3be5e328c4cd207e2/src/gui/folderwatcher.cpp#L40-L40
+        while (t.duration() < 15s) {
             // Check if it was already reported as changed by the watcher
             for (int i = 0; i < _pathChangedSpy->size(); ++i) {
                 const auto &args = _pathChangedSpy->at(i);
@@ -92,7 +107,7 @@ class TestFolderWatcher : public QObject
                     return true;
             }
             // Wait a bit and test again (don't bother checking if we timed out or not)
-            _pathChangedSpy->wait(200);
+            _pathChangedSpy->wait(1000);
         }
         return false;
     }
@@ -114,12 +129,12 @@ public:
         rootDir.mkpath(QStringLiteral("a1/b2/c1"));
         rootDir.mkpath(QStringLiteral("a1/b3/c3"));
         rootDir.mkpath(QStringLiteral("a2/b3/c3"));
-        TestUtils::writeRandomFile(_rootPath + "/a1/random.bin");
-        TestUtils::writeRandomFile(_rootPath + "/a1/b2/todelete.bin");
-        TestUtils::writeRandomFile(_rootPath + "/a2/renamefile");
-        TestUtils::writeRandomFile(_rootPath + "/a1/movefile");
+        TestUtils::writeRandomFile(_rootPath + QStringLiteral("/a1/random.bin"));
+        TestUtils::writeRandomFile(_rootPath + QStringLiteral("/a1/b2/todelete.bin"));
+        TestUtils::writeRandomFile(_rootPath + QStringLiteral("/a2/renamefile"));
+        TestUtils::writeRandomFile(_rootPath + QStringLiteral("/a1/movefile"));
 
-        _watcher.reset(new FolderWatcher);
+        _watcher.reset(new FolderWatcherForTests);
         _watcher->init(_rootPath);
         _pathChangedSpy.reset(new QSignalSpy(_watcher.data(), &FolderWatcher::pathChanged));
     }
@@ -129,11 +144,11 @@ public:
         int n = 0;
         const auto &entryList = QDir(path).entryList(QDir::Dirs | QDir::NoDotAndDotDot);
         for (const auto &sub : entryList)
-            n += 1 + countFolders(path + '/' + sub);
+            n += 1 + countFolders(path + QLatin1Char('/') + sub);
         return n;
     }
 
-private slots:
+private Q_SLOTS:
     void init()
     {
         _pathChangedSpy->clear();
@@ -146,40 +161,40 @@ private slots:
     }
 
     void testACreate() { // create a new file
-        QString file(_rootPath + "/foo.txt");
+        QString file(_rootPath + QStringLiteral("/foo.txt"));
         QString cmd;
         cmd = QStringLiteral("echo \"xyz\" > %1").arg(file);
         qDebug() << "Command: " << cmd;
-        system(cmd.toLocal8Bit());
+        system(cmd.toLocal8Bit().constData());
 
         QVERIFY(waitForPathChanged(file));
     }
 
     void testATouch() { // touch an existing file.
-        QString file(_rootPath + "/a1/random.bin");
+        QString file(_rootPath + QStringLiteral("/a1/random.bin"));
         touch(file);
         QVERIFY(waitForPathChanged(file));
     }
 
     void testCreateADir() {
-        QString file(_rootPath+"/a1/b1/new_dir");
+        QString file(_rootPath + QStringLiteral("/a1/b1/new_dir"));
         mkdir(file);
         QVERIFY(waitForPathChanged(file));
 
         // Notifications from that new folder arrive too
-        QString file2(_rootPath + "/a1/b1/new_dir/contained");
+        QString file2(_rootPath + QStringLiteral("/a1/b1/new_dir/contained"));
         touch(file2);
         QVERIFY(waitForPathChanged(file2));
     }
 
     void testRemoveADir() {
-        QString file(_rootPath+"/a1/b3/c3");
+        QString file(_rootPath + QStringLiteral("/a1/b3/c3"));
         rmdir(file);
         QVERIFY(waitForPathChanged(file));
     }
 
     void testRemoveAFile() {
-        QString file(_rootPath+"/a1/b2/todelete.bin");
+        QString file(_rootPath + QStringLiteral("/a1/b2/todelete.bin"));
         QVERIFY(QFile::exists(file));
         rm(file);
         QVERIFY(!QFile::exists(file));
@@ -188,8 +203,8 @@ private slots:
     }
 
     void testRenameAFile() {
-        QString file1(_rootPath+"/a2/renamefile");
-        QString file2(_rootPath+"/a2/renamefile.renamed");
+        QString file1(_rootPath + QStringLiteral("/a2/renamefile"));
+        QString file2(_rootPath + QStringLiteral("/a2/renamefile.renamed"));
         QVERIFY(QFile::exists(file1));
         mv(file1, file2);
         QVERIFY(QFile::exists(file2));
@@ -199,8 +214,8 @@ private slots:
     }
 
     void testMoveAFile() {
-        QString old_file(_rootPath+"/a1/movefile");
-        QString new_file(_rootPath+"/a2/movefile.renamed");
+        QString old_file(_rootPath + QStringLiteral("/a1/movefile"));
+        QString new_file(_rootPath + QStringLiteral("/a2/movefile.renamed"));
         QVERIFY(QFile::exists(old_file));
         mv(old_file, new_file);
         QVERIFY(QFile::exists(new_file));
@@ -210,8 +225,8 @@ private slots:
     }
 
     void testRenameDirectorySameBase() {
-        QString old_file(_rootPath+"/a1/b1");
-        QString new_file(_rootPath+"/a1/brename");
+        QString old_file(_rootPath + QStringLiteral("/a1/b1"));
+        QString new_file(_rootPath + QStringLiteral("/a1/brename"));
         QVERIFY(QFile::exists(old_file));
         mv(old_file, new_file);
         QVERIFY(QFile::exists(new_file));
@@ -221,18 +236,18 @@ private slots:
 
         // Verify that further notifications end up with the correct paths
 
-        QString file(_rootPath+"/a1/brename/c1/random.bin");
+        QString file(_rootPath + QStringLiteral("/a1/brename/c1/random.bin"));
         touch(file);
         QVERIFY(waitForPathChanged(file));
 
-        QString dir(_rootPath+"/a1/brename/newfolder");
+        QString dir(_rootPath + QStringLiteral("/a1/brename/newfolder"));
         mkdir(dir);
         QVERIFY(waitForPathChanged(dir));
     }
 
     void testRenameDirectoryDifferentBase() {
-        QString old_file(_rootPath+"/a1/brename");
-        QString new_file(_rootPath+"/bren");
+        QString old_file(_rootPath + QStringLiteral("/a1/brename"));
+        QString new_file(_rootPath + QStringLiteral("/bren"));
         QVERIFY(QFile::exists(old_file));
         mv(old_file, new_file);
         QVERIFY(QFile::exists(new_file));
@@ -242,11 +257,11 @@ private slots:
 
         // Verify that further notifications end up with the correct paths
 
-        QString file(_rootPath+"/bren/c1/random.bin");
+        QString file(_rootPath + QStringLiteral("/bren/c1/random.bin"));
         touch(file);
         QVERIFY(waitForPathChanged(file));
 
-        QString dir(_rootPath+"/bren/newfolder2");
+        QString dir(_rootPath + QStringLiteral("/bren/newfolder2"));
         mkdir(dir);
         QVERIFY(waitForPathChanged(dir));
     }
