@@ -25,23 +25,24 @@ public:
 namespace OCC {
 
 namespace TestUtils {
-    AccountPtr createDummyAccount()
+    TestUtilsPrivate::AccountStateRaii createDummyAccount()
     {
+        // ensure we have an instance of folder man
+        std::ignore = folderMan();
         // don't use the account manager to create the account, it would try to use widgets
         auto acc = Account::create(QUuid::createUuid());
         HttpCredentialsTest *cred = new HttpCredentialsTest(QStringLiteral("testuser"), QStringLiteral("secret"));
         acc->setCredentials(cred);
         acc->setUrl(QUrl(QStringLiteral("http://localhost/owncloud")));
         acc->setDavDisplayName(QStringLiteral("fakename") + acc->uuid().toString(QUuid::WithoutBraces));
-        acc->setCapabilities(OCC::TestUtils::testCapabilities());
-        OCC::AccountManager::instance()->addAccount(acc);
-        return acc;
+        acc->setCapabilities({acc->url(), OCC::TestUtils::testCapabilities()});
+        return {OCC::AccountManager::instance()->addAccount(acc).get(), &TestUtilsPrivate::accountStateDeleter};
     }
 
     FolderDefinition createDummyFolderDefinition(const AccountPtr &account, const QString &path)
     {
         // TODO: legacy
-        auto d = OCC::FolderDefinition::createNewFolderDefinition(account->davUrl());
+        auto d = OCC::FolderDefinition::createNewFolderDefinition(account->davUrl(), {});
         d.setLocalPath(path);
         d.setTargetPath(path);
         return d;
@@ -56,7 +57,7 @@ namespace TestUtils {
     {
         static QPointer<FolderMan> man;
         if (!man) {
-            man = new FolderMan;
+            man = FolderMan::createInstance().release();
             QObject::connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit, man, &FolderMan::deleteLater);
         };
         return man;
@@ -94,16 +95,27 @@ namespace TestUtils {
         static const auto algorithmNames = [] {
             QVariantList out;
             for (const auto &a : CheckSums::All) {
-                out.append(CheckSums::toQString(a.first));
+                out.append(Utility::enumToString(a.first));
             }
             return out;
         }();
-        return {
-            { "core", QVariantMap { { "status", QVariantMap { { "installed", "1" }, { "maintenance", "0" }, { "needsDbUpgrade", "0" }, { "version", "10.11.0.0" }, { "versionstring", "10.11.0" }, { "edition", "Community" }, { "productname", "Infinite Scale" }, { "product", "Infinite Scale" }, { "productversion", "2.0.0-beta1+7c2e3201b" } } } } },
-            { "files", QVariantList {} },
-            { "dav", QVariantMap { { "chunking", "1.0" } } },
-            { "checksums", QVariantMap { { "preferredUploadType", CheckSums::toQString(algo) }, { "supportedTypes", algorithmNames } } }
-        };
+        return {{QStringLiteral("core"),
+                    QVariantMap{{QStringLiteral("status"),
+                        QVariantMap{{QStringLiteral("installed"), QStringLiteral("1")}, {QStringLiteral("maintenance"), QStringLiteral("0")},
+                            {QStringLiteral("needsDbUpgrade"), QStringLiteral("0")}, {QStringLiteral("version"), QStringLiteral("10.11.0.0")},
+                            {QStringLiteral("versionstring"), QStringLiteral("10.11.0")}, {QStringLiteral("edition"), QStringLiteral("Community")},
+                            {QStringLiteral("productname"), QStringLiteral("Infinite Scale")}, {QStringLiteral("product"), QStringLiteral("Infinite Scale")},
+                            {QStringLiteral("productversion"), QStringLiteral("2.0.0-beta1+7c2e3201b")}}}}},
+            {QStringLiteral("files"), QVariantList{}}, {QStringLiteral("dav"), QVariantMap{{QStringLiteral("chunking"), QStringLiteral("1.0")}}},
+            {QStringLiteral("checksums"),
+                QVariantMap{{QStringLiteral("preferredUploadType"), Utility::enumToString(algo)}, {QStringLiteral("supportedTypes"), algorithmNames}}}};
+    }
+
+    void TestUtilsPrivate::accountStateDeleter(OCC::AccountState *acc)
+    {
+        if (acc) {
+            OCC::AccountManager::instance()->deleteAccount(acc);
+        }
     }
 }
 }
